HostFunctionContext

Struct HostFunctionContext 

pub struct HostFunctionContext {
    pub plugin_name: String,
    pub capabilities: WasmPluginCapabilities,
    pub audit_log: Vec<AuditEntry>,
    pub transaction_id: Option<u64>,
    pub session_vars: HashMap<String, Vec<u8>>,
}
Context passed to host function implementations

Contains the plugin’s capabilities and access to database resources.

Fields

plugin_name: String

Plugin name (for logging)

capabilities: WasmPluginCapabilities

Plugin capabilities

audit_log: Vec<AuditEntry>

Audit log for this call chain

transaction_id: Option<u64>

Current transaction ID (if any)

session_vars: HashMap<String, Vec<u8>>

Session variables

Implementations

Source

impl HostFunctionContext

pub fn new(plugin_name: &str, capabilities: WasmPluginCapabilities) -> Self

Create a new context for a plugin

pub fn check_read(&self, table: &str) -> KernelResult<()>

Check if the plugin can read from a table

pub fn check_write(&self, table: &str) -> KernelResult<()>

Check if the plugin can write to a table

Check if the plugin can perform vector search

Check if the plugin can perform index search

pub fn audit( &mut self, function: &str, table: Option<&str>, status: i32, rows: u64, )

Add an audit entry